#define __GraphicsState_cc__

#include "GraphicsState.h"

GraphicsState::GraphicsState() {
        gamma = 1.1;
        fontSize = 12;
        use_multitex = true;
        has_multitex = false;
        show_cursor = true;
        show_stats = false;
        swap_RB = false;
        polygon_smooth_ok = true;
        grab_input = true;
        total_fps = 0;
        graphics_time = 0;
        graphics_fps = 0;
        num_surfs = 0;
        num_ents = 0;
        physics_time = 0;
        physics_fps = 0;
}


#undef __GraphicsState_cc__
